.. _tableofcontents:

=================
Table of Contents
=================

.. toctree::
   :hidden:

   index

.. toctree::
   :maxdepth: 3

   guides/index
   coderef/index


Indices, glossary and tables
============================

* :ref:`genindex`
